.. _github-stats-3-4-3:

GitHub statistics for 3.4.3 (August 21, 2021)
=============================================

GitHub statistics for 2021/05/08 - 2021/08/12 (tag: v3.4.2)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 22 issues and merged 69 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/64?closed=1>`__

The following 20 authors contributed 95 commits.

* Antony Lee
* David Stansby
* Diego
* Diego Leal Petrola
* Diego Petrola
* Elliott Sales de Andrade
* Eric Firing
* Frank Sauerburger
* Greg Lucas
* Ian Hunt-Isaak
* Jash Shah
* Jody Klymak
* Jouni K. Seppänen
* Michał Górny
* sandipanpanda
* Slava Ostroukh
* Thomas A Caswell
* Tim Hoffmann
* Viacheslav Ostroukh
* Xianxiang Li

GitHub issues and pull requests:

Pull Requests (69):

* :ghpull:`20830`: Backport PR #20826 on branch v3.4.x (Fix clear of Axes that are shared.)
* :ghpull:`20826`: Fix clear of Axes that are shared.
* :ghpull:`20823`: Backport PR #20817 on branch v3.4.x (Make test_change_epoch more robust.)
* :ghpull:`20817`: Make test_change_epoch more robust.
* :ghpull:`20820`: Backport PR #20771 on branch v3.4.x (FIX: tickspacing for subfigures)
* :ghpull:`20771`: FIX: tickspacing for subfigures
* :ghpull:`20777`: FIX: dpi and scatter for subfigures now correct
* :ghpull:`20787`: Backport PR #20786 on branch v3.4.x (Fixed typo in _constrained_layout.py (#20782))
* :ghpull:`20786`: Fixed typo in _constrained_layout.py (#20782)
* :ghpull:`20763`: Backport PR #20761 on branch v3.4.x (Fix suplabel autopos)
* :ghpull:`20761`: Fix suplabel autopos
* :ghpull:`20751`: Backport PR #20748 on branch v3.4.x (Ensure _static directory exists before copying CSS.)
* :ghpull:`20748`: Ensure _static directory exists before copying CSS.
* :ghpull:`20713`: Backport PR #20710 on branch v3.4.x (Fix tests with Inkscape 1.1.)
* :ghpull:`20687`: Enable PyPy wheels for v3.4.x
* :ghpull:`20710`: Fix tests with Inkscape 1.1.
* :ghpull:`20696`: Backport PR #20662 on branch v3.4.x (Don't forget to disable autoscaling after interactive zoom.)
* :ghpull:`20662`: Don't forget to disable autoscaling after interactive zoom.
* :ghpull:`20683`: Backport PR #20645 on branch v3.4.x (Fix leak if affine_transform is passed invalid vertices.)
* :ghpull:`20645`: Fix leak if affine_transform is passed invalid vertices.
* :ghpull:`20642`: Backport PR #20629 on branch v3.4.x (Add protection against out-of-bounds read in ttconv)
* :ghpull:`20643`: Backport PR #20597 on branch v3.4.x
* :ghpull:`20629`: Add protection against out-of-bounds read in ttconv
* :ghpull:`20597`: Fix TTF headers for type 42 stix font
* :ghpull:`20624`: Backport PR #20609 on branch v3.4.x (FIX: fix figbox deprecation)
* :ghpull:`20609`: FIX: fix figbox deprecation
* :ghpull:`20594`: Backport PR #20590 on branch v3.4.x (Fix class docstrings for Norms created from Scales.)
* :ghpull:`20590`: Fix class docstrings for Norms created from Scales.
* :ghpull:`20587`: Backport PR #20584: FIX: do not simplify path in LineCollection.get_s…
* :ghpull:`20584`: FIX: do not simplify path in LineCollection.get_segments
* :ghpull:`20578`: Backport PR #20511 on branch v3.4.x (Fix calls to np.ma.masked_where)
* :ghpull:`20511`: Fix calls to np.ma.masked_where
* :ghpull:`20568`: Backport PR #20565 on branch v3.4.x (FIX: PILLOW asarray bug)
* :ghpull:`20566`: Backout pillow=8.3.0 due to a crash
* :ghpull:`20565`: FIX: PILLOW asarray bug
* :ghpull:`20503`: Backport PR #20488 on branch v3.4.x (FIX: Include 0 when checking lognorm vmin)
* :ghpull:`20488`: FIX: Include 0 when checking lognorm vmin
* :ghpull:`20483`: Backport PR #20480 on branch v3.4.x (Fix str of empty polygon.)
* :ghpull:`20480`: Fix str of empty polygon.
* :ghpull:`20478`: Backport PR #20473 on branch v3.4.x (_GSConverter: handle stray 'GS' in output gracefully)
* :ghpull:`20473`: _GSConverter: handle stray 'GS' in output gracefully
* :ghpull:`20456`: Backport PR #20453 on branch v3.4.x (Remove ``Tick.apply_tickdir`` from 3.4 deprecations.)
* :ghpull:`20441`: Backport PR #20416 on branch v3.4.x (Fix missing Patch3DCollection._z_markers_idx)
* :ghpull:`20416`: Fix missing Patch3DCollection._z_markers_idx
* :ghpull:`20417`: Backport PR #20395 on branch v3.4.x (Pathing issue)
* :ghpull:`20395`: Pathing issue
* :ghpull:`20404`: Backport PR #20403: FIX: if we have already subclassed mixin class ju…
* :ghpull:`20403`: FIX: if we have already subclassed mixin class just return
* :ghpull:`20383`: Backport PR #20381 on branch v3.4.x (Prevent corrections and completions in search field)
* :ghpull:`20307`: Backport PR #20154 on branch v3.4.x (ci: Bump Ubuntu to 18.04 LTS.)
* :ghpull:`20285`: Backport PR #20275 on branch v3.4.x (Fix some examples that are skipped in docs build)
* :ghpull:`20275`: Fix some examples that are skipped in docs build
* :ghpull:`20267`: Backport PR #20265 on branch v3.4.x (Legend edgecolor face)
* :ghpull:`20265`: Legend edgecolor face
* :ghpull:`20260`: Fix legend edgecolor face
* :ghpull:`20259`: Backport PR #20248 on branch v3.4.x (Replace pgf image-streaming warning by error.)
* :ghpull:`20248`: Replace pgf image-streaming warning by error.
* :ghpull:`20241`: Backport PR #20212 on branch v3.4.x (Update span_selector.py)
* :ghpull:`20212`: Update span_selector.py
* :ghpull:`19980`: Tidy up deprecation messages in ``_subplots.py``
* :ghpull:`20234`: Backport PR #20225 on branch v3.4.x (FIX: correctly handle ax.legend(..., legendcolor='none'))
* :ghpull:`20225`: FIX: correctly handle ax.legend(..., legendcolor='none')
* :ghpull:`20232`: Backport PR #19636 on branch v3.4.x (Correctly check inaxes for multicursor)
* :ghpull:`20228`: Backport PR #19849 on branch v3.4.x (FIX DateFormatter for month names when usetex=True)
* :ghpull:`19849`: FIX DateFormatter for month names when usetex=True
* :ghpull:`20154`: ci: Bump Ubuntu to 18.04 LTS.
* :ghpull:`20186`: Backport PR #19975 on branch v3.4.x (CI: remove workflow to push commits to macpython/matplotlib-wheels)
* :ghpull:`19975`: CI: remove workflow to push commits to macpython/matplotlib-wheels
* :ghpull:`19636`: Correctly check inaxes for multicursor

Issues (22):

* :ghissue:`20219`: Regression: undocumented change of behaviour in mpl 3.4.2 with axis ticks direction
* :ghissue:`20721`: ax.clear() adds extra ticks, un-hides shared-axis tick labels
* :ghissue:`20765`: savefig re-scales xticks and labels of some (but not all) subplots
* :ghissue:`20782`: [Bug]: _supylabel get_in_layout() typo?
* :ghissue:`20747`: [Bug]: _copy_css_file assumes that the _static directory already exists
* :ghissue:`20617`: tests fail with new inkscape
* :ghissue:`20519`: Toolbar zoom doesn't change autoscale status for versions 3.2.0 and above
* :ghissue:`20628`: Out-of-bounds read leads to crash or broken TrueType fonts
* :ghissue:`20612`: Broken EPS for Type 42 STIX
* :ghissue:`19982`: regression for 3.4.x - ax.figbox replacement incompatible to all version including 3.3.4
* :ghissue:`19938`: unuseful deprecation warning figbox
* :ghissue:`16400`: Inconsistent behavior between Normalizers when input is Dataframe
* :ghissue:`20583`: Lost class descriptions since 3.4 docs
* :ghissue:`20551`: set_segments(get_segments()) makes lines coarse
* :ghissue:`20560`: test_png is failing
* :ghissue:`20487`: test_huge_range_log is failing...
* :ghissue:`20472`: test_backend_pgf.py::test_xelatex[pdf] - ValueError: invalid literal for int() with base 10: b'ate missing from Resources. [...]
* :ghissue:`20328`: Path.intersects_path sometimes returns incorrect values
* :ghissue:`20258`: Using edgecolors='face' with stackplot causes value error when using plt.legend()
* :ghissue:`20200`: examples/widgets/span_selector.py is brittle
* :ghissue:`20231`: MultiCursor bug
* :ghissue:`19836`: Month names not set as text when using usetex
